@@ -3,12 +3,13 @@ library(balance)
 data(expenditures, package = "robCompositions")
 y1 <- data.frame(c(1,1,1,-1,-1),c(1,-1,-1,0,0),
                  c(0,+1,-1,0,0),c(0,0,0,+1,-1))
+rownames(y1) <- colnames(expenditures)
 colnames(y1) <- paste0("z", 1:4)
 
 a <- robCompositions::balances(expenditures, y1)[[1]]
 colnames(a) <- paste0("z", 1:4)
 rownames(a) <- as.character(1:nrow(a))
-b <- apply(y1, 2, function(z) balance.fromContrast(expenditures, z))
+b <- apply(y1, 2, function(z) balance:::balance.fromContrast(expenditures, z))
 rownames(b) <- as.character(1:nrow(b))
 c <- balance::balance.fromSBP(expenditures, y1)
 
